@@ -142,3 +142,10 @@ class BatchML(Example):
         data_sources_dict["batch_size"] = data_sources_dict["satellite"].batch_size
 
         return BatchML(**data_sources_dict)
+
+    def normalize(self):
+        """ Normalize the batch """
+        
+        # loop over all data sources and normalize
+        for data_sources in self.data_sources:
+            data_sources.normalize()
